@@ -84,7 +84,7 @@ oos_vintage_forc <- function(lm_call, time_vec, ..., estimation_window = NULL, r
   num_coefs <- length(lm_call$coefficients)
 
   # Input validation.
-  if (class(lm_call) != "lm") {
+  if (inherits(lm_call , "lm") == FALSE) {
     stop("* lm_call must be must be of the lm function form: lm_call = lm(y = x1 + x2, data)")
   }
 
@@ -161,7 +161,7 @@ oos_vintage_forc <- function(lm_call, time_vec, ..., estimation_window = NULL, r
     } else {
       train_data <- lm_call$model[time_vec <= origin_vec[i], ]
       if ((nrow(train_data) - estimation_window) >= 1) {
-        train_data <- train_data[((nrow(train_data) - estimation_window):nrow(train_data)), ]
+        train_data <- train_data[((nrow(train_data) - estimation_window + 1):nrow(train_data)), ]
       }
     }
     
